@@ -1,6 +1,7 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ *   ASResource.cpp
  *
- *   Copyright (C) 2006-2010 by Jim Pattee <jimp03@email.com>
+ *   Copyright (C) 2006-2011 by Jim Pattee <jimp03@email.com>
  *   Copyright (C) 1998-2002 by Tal Davidson
  *   <http://www.gnu.org/licenses/lgpl-3.0.html>
  *
@@ -56,8 +57,13 @@ const string ASResource::AS_TEMPLATE = string("template");
 const string ASResource::AS_TRY = string("try");
 const string ASResource::AS_CATCH = string("catch");
 const string ASResource::AS_FINALLY = string("finally");
+const string ASResource::_AS_TRY = string("__try");
+const string ASResource::_AS_FINALLY = string("__finally");
+const string ASResource::_AS_EXCEPT = string("__except");
 const string ASResource::AS_THROWS = string("throws");
 const string ASResource::AS_CONST = string("const");
+const string ASResource::AS_SEALED = string("sealed");
+const string ASResource::AS_OVERRIDE = string("override");
 const string ASResource::AS_WHERE = string("where");
 const string ASResource::AS_NEW = string("new");
 
@@ -230,9 +236,17 @@ void ASResource::buildHeaders(vector<const string*>* headers, int fileType, bool
 	headers->push_back(&AS_WHILE);
 	headers->push_back(&AS_DO);
 	headers->push_back(&AS_SWITCH);
+	headers->push_back(&AS_CASE);
+	headers->push_back(&AS_DEFAULT);
 	headers->push_back(&AS_TRY);
 	headers->push_back(&AS_CATCH);
 
+	if (fileType == C_TYPE)
+	{
+		headers->push_back(&_AS_TRY);		// __try
+		headers->push_back(&_AS_FINALLY);	// __finally
+		headers->push_back(&_AS_EXCEPT);	// __except
+	}
 	if (fileType == JAVA_TYPE)
 	{
 		headers->push_back(&AS_FINALLY);
@@ -244,7 +258,6 @@ void ASResource::buildHeaders(vector<const string*>* headers, int fileType, bool
 		headers->push_back(&AS_FINALLY);
 		headers->push_back(&AS_FOREACH);
 		headers->push_back(&AS_LOCK);
-//      headers->push_back(&AS_UNSAFE);
 		headers->push_back(&AS_FIXED);
 		headers->push_back(&AS_GET);
 		headers->push_back(&AS_SET);
@@ -254,14 +267,9 @@ void ASResource::buildHeaders(vector<const string*>* headers, int fileType, bool
 
 	if (beautifier)
 	{
-		headers->push_back(&AS_CASE);
-		headers->push_back(&AS_DEFAULT);
-
 		if (fileType == C_TYPE)
 		{
-			headers->push_back(&AS_CONST);
 			headers->push_back(&AS_TEMPLATE);
-			headers->push_back(&AS_VOLATILE);
 		}
 
 		if (fileType == JAVA_TYPE)
@@ -281,9 +289,6 @@ void ASResource::buildHeaders(vector<const string*>* headers, int fileType, bool
 void ASResource::buildIndentableHeaders(vector<const string*>* indentableHeaders)
 {
 	indentableHeaders->push_back(&AS_RETURN);
-//	indentableHeaders->push_back(&AS_COUT);
-//	indentableHeaders->push_back(&AS_CERR);
-//	indentableHeaders->push_back(&AS_CIN);
 
 	sort(indentableHeaders->begin(), indentableHeaders->end(), sortOnName);
 }
@@ -316,7 +321,8 @@ void ASResource::buildNonAssignmentOperators(vector<const string*>* nonAssignmen
 
 /**
  * Build the vector of header non-paren headers.
- * Used by BOTH ASFormatter.cpp and ASBeautifier.cpp
+ * Used by BOTH ASFormatter.cpp and ASBeautifier.cpp.
+ * NOTE: Non-paren headers should also be included in the headers vector.
  *
  * @param nonParenHeaders       a reference to the vector to be built.
  */
@@ -325,7 +331,15 @@ void ASResource::buildNonParenHeaders(vector<const string*>* nonParenHeaders, in
 	nonParenHeaders->push_back(&AS_ELSE);
 	nonParenHeaders->push_back(&AS_DO);
 	nonParenHeaders->push_back(&AS_TRY);
+	nonParenHeaders->push_back(&AS_CATCH);		// can be paren or non-paren
+	nonParenHeaders->push_back(&AS_CASE);		// can be paren or non-paren
+	nonParenHeaders->push_back(&AS_DEFAULT);
 
+	if (fileType == C_TYPE)
+	{
+		nonParenHeaders->push_back(&_AS_TRY);		// __try
+		nonParenHeaders->push_back(&_AS_FINALLY);	// __finally
+	}
 	if (fileType == JAVA_TYPE)
 	{
 		nonParenHeaders->push_back(&AS_FINALLY);
@@ -333,9 +347,7 @@ void ASResource::buildNonParenHeaders(vector<const string*>* nonParenHeaders, in
 
 	if (fileType == SHARP_TYPE)
 	{
-		nonParenHeaders->push_back(&AS_CATCH);       // can be a paren or non-paren header
 		nonParenHeaders->push_back(&AS_FINALLY);
-//      nonParenHeaders->push_back(&AS_UNSAFE);
 		nonParenHeaders->push_back(&AS_GET);
 		nonParenHeaders->push_back(&AS_SET);
 		nonParenHeaders->push_back(&AS_ADD);
@@ -344,13 +356,9 @@ void ASResource::buildNonParenHeaders(vector<const string*>* nonParenHeaders, in
 
 	if (beautifier)
 	{
-		nonParenHeaders->push_back(&AS_CASE);
-		nonParenHeaders->push_back(&AS_DEFAULT);
 		if (fileType == C_TYPE)
 		{
-			nonParenHeaders->push_back(&AS_CONST);
 			nonParenHeaders->push_back(&AS_TEMPLATE);
-			nonParenHeaders->push_back(&AS_VOLATILE);
 		}
 		if (fileType == JAVA_TYPE)
 		{
@@ -450,15 +458,21 @@ void ASResource::buildPreBlockStatements(vector<const string*>* preBlockStatemen
 
 /**
  * Build the vector of pre-command headers.
- * Used by ONLY ASFormatter.cpp
+ * Used by BOTH ASFormatter.cpp and ASBeautifier.cpp.
+ * NOTE: Cannot be both a header and a preCommandHeader.
  *
- * @param preCommandHeaders     a reference to the vector to be built.
+ * A preCommandHeader is in a function definition between
+ * the closing paren and the opening bracket.
+ * e.g. in "void foo() const {}", "const" is a preCommandHeader.
  */
 void ASResource::buildPreCommandHeaders(vector<const string*>* preCommandHeaders, int fileType)
 {
 	if (fileType == C_TYPE)
 	{
 		preCommandHeaders->push_back(&AS_CONST);
+		preCommandHeaders->push_back(&AS_VOLATILE);
+		preCommandHeaders->push_back(&AS_SEALED);		// Visual C only
+		preCommandHeaders->push_back(&AS_OVERRIDE);		// Visual C only
 	}
 
 	if (fileType == JAVA_TYPE)
