@@ -2,7 +2,7 @@
                      htmlgenerator.cpp  -  description
                              -------------------
     begin                : Wed Nov 28 2001
-    copyright            : (C) 2001-2007 by Andre Simon
+    copyright            : (C) 2001-2010 by Andre Simon
     email                : andre.simon1@gmx.de
  ***************************************************************************/
 
@@ -28,6 +28,7 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #include <fstream>
 #include <iostream>
 #include <sstream>
+#include <algorithm>
 
 #include "htmlgenerator.h"
 #include "version.h"
@@ -71,11 +72,11 @@ namespace highlight
 			else
 			{
 				os << "<link rel=\"stylesheet\" type=\"text/css\" href=\""
-				<< getStyleOutputPath()
-				<< "\">\n";
+				    << getStyleOutputPath()
+				    << "\">\n";
 			}
 			os << "</head>\n<body class=\"" << cssClassName
-			<< "\">\n";
+			    << "\">\n";
 		}
 		else
 		{
@@ -134,20 +135,18 @@ namespace highlight
 		openTags.push_back ( "" );
 		if ( useInlineCSS )
 		{
-			//embedBlockOpen = "<div  style=\"background-color:#efefef;\">";
 			openTags.push_back ( getOpenTag ( docStyle.getStringStyle() ) );
 			openTags.push_back ( getOpenTag ( docStyle.getNumberStyle() ) );
 			openTags.push_back ( getOpenTag ( docStyle.getSingleLineCommentStyle() ) );
 			openTags.push_back ( getOpenTag ( docStyle.getCommentStyle() ) );
 			openTags.push_back ( getOpenTag ( docStyle.getEscapeCharStyle() ) );
-			openTags.push_back ( getOpenTag ( docStyle.getDirectiveStyle() ) );
-			openTags.push_back ( getOpenTag ( docStyle.getDirectiveStringStyle() ) );
+			openTags.push_back ( getOpenTag ( docStyle.getPreProcessorStyle() ) );
+			openTags.push_back ( getOpenTag ( docStyle.getPreProcStringStyle() ) );
 			openTags.push_back ( getOpenTag ( docStyle.getLineStyle() ) );
-			openTags.push_back ( getOpenTag ( docStyle.getSymbolStyle() ) );
+			openTags.push_back ( getOpenTag ( docStyle.getOperatorStyle() ) );
 		}
 		else
 		{
-			//embedBlockOpen = "<div  style=\"background-color:#efefef;\">";
 			openTags.push_back ( getOpenTag ( STY_NAME_STR ) );
 			openTags.push_back ( getOpenTag ( STY_NAME_NUM ) );
 			openTags.push_back ( getOpenTag ( STY_NAME_SLC ) );
@@ -160,11 +159,11 @@ namespace highlight
 		}
 
 		closeTags.push_back ( "" );
-		for ( int i=1;i<NUMBER_BUILTIN_STATES; i++ )
+		for (unsigned int i=1;i<NUMBER_BUILTIN_STATES; i++ )
 		{
 			closeTags.push_back ( "</span>" );
 		}
-		//embedBlockClose = "</div>";
+
 	}
 
 	string  HtmlGenerator::getAttributes ( const string & elemName, const ElementStyle & elem )
@@ -237,19 +236,13 @@ namespace highlight
 			os << getAttributes ( STY_NAME_NUM, docStyle.getNumberStyle() )
 			<< getAttributes ( STY_NAME_ESC, docStyle.getEscapeCharStyle() )
 			<< getAttributes ( STY_NAME_STR, docStyle.getStringStyle() )
-			<< getAttributes ( STY_NAME_DST, docStyle.getDirectiveStringStyle() )
+			<< getAttributes ( STY_NAME_DST, docStyle.getPreProcStringStyle() )
 			<< getAttributes ( STY_NAME_SLC, docStyle.getSingleLineCommentStyle() )
 			<< getAttributes ( STY_NAME_COM, docStyle.getCommentStyle() )
-			<< getAttributes ( STY_NAME_DIR, docStyle.getDirectiveStyle() )
-			<< getAttributes ( STY_NAME_SYM, docStyle.getSymbolStyle() )
+			<< getAttributes ( STY_NAME_DIR, docStyle.getPreProcessorStyle() )
+			<< getAttributes ( STY_NAME_SYM, docStyle.getOperatorStyle() )
 			<< getAttributes ( STY_NAME_LIN, docStyle.getLineStyle() );
 
-			os << "."<<cssClassName<<".mark\t{ background-color:#"
-			<< ( docStyle.getMarkLineColour().getRed ( HTML ) )
-			<< ( docStyle.getMarkLineColour().getGreen ( HTML ) )
-			<< ( docStyle.getMarkLineColour().getBlue ( HTML ) )
-			<< ";}\n";
-
 			KeywordStyles styles = docStyle.getKeywordStyles();
 			for ( KSIterator it=styles.begin(); it!=styles.end(); it++ )
 			{
@@ -291,14 +284,11 @@ namespace highlight
 
 		string nlStr;
 
-		if ( markLines.count ( lineNumber-1 ) ) nlStr +="</span>";
-
 		if ( showLineNumbers && orderedList ) nlStr +="</li>";
 		/// set wrapping arrow if previous line was wrapped
 		//else if (preFormatter.isWrappedLine(lineNumber-1)) nlStr += "&crarr;";
 
 		if (printNewLines) nlStr+="\n";
-		
 		return nlStr;
 	}
 
@@ -347,28 +337,6 @@ namespace highlight
 			wsBuffer += numberPrefix.str();
 		}
 
-		if ( markLines.count ( lineNumber ) )
-		{
-			if ( useInlineCSS )
-			{
-				ostringstream markingFmt;
-				markingFmt <<"<span style=\""
-				<<"background-color:#"
-				<< ( docStyle.getMarkLineColour().getRed ( HTML ) )
-				<< ( docStyle.getMarkLineColour().getGreen ( HTML ) )
-				<< ( docStyle.getMarkLineColour().getBlue ( HTML ) )
-				<< ";\"";
-				wsBuffer+=markingFmt.str();
-			}
-			else
-			{
-				wsBuffer +="<span class=\""+cssClassName+" mark\"";
-			}
-			if ( !markLines[lineNumber].empty() )
-				wsBuffer +=" title=\""+markLines[lineNumber]+"\"";
-			wsBuffer +=">";
-		}
-
 	}
 
 	string HtmlGenerator::getHeaderStart ( const string &title )
@@ -382,9 +350,7 @@ namespace highlight
 			<< encoding
 			<< "\">\n";
 		}
-		header << "<title>"
-		<< title
-		<< "</title>\n";
+		header << "<title>" << title << "</title>\n";
 		return header.str();
 	}
 
@@ -399,10 +365,11 @@ namespace highlight
 		{
 			string inFileName;
 			string inFilePath, newInFilePath;
+			set<string> usedFileNames;
 			indexfile << getHeaderStart ( "Source Index" );
 			indexfile << "</head>\n<body>\n<h1> Source Index</h1>\n"
-			<< hrTag
-			<<  "\n<ul>\n";
+				  << hrTag
+				  <<  "\n<ul>\n";
 			string::size_type pos;
 			for ( unsigned int i=0; i < fileList.size();  i++ )
 			{
@@ -423,6 +390,15 @@ namespace highlight
 					inFilePath=newInFilePath;
 				}
 				inFileName = ( fileList[i] ).substr ( pos+1 );
+
+				if (usedFileNames.count(inFileName)){
+				  string prefix=fileList[i].substr (0, pos+1 );
+				  replace (prefix.begin(), prefix.end(), Platform::pathSeparator, '_');
+				  inFileName.insert(0, prefix);
+				} else {
+				  usedFileNames.insert(inFileName);
+				}
+
 				indexfile << "<li><a href=\"" << inFileName << suffix << "\">";
 				indexfile << inFileName << suffix <<"</a></li>\n";
 			}
@@ -446,9 +422,9 @@ namespace highlight
 	{
 		if ( useInlineCSS )
 		{
-			return getOpenTag ( docStyle.getKeywordStyle ( langInfo.getKeywordClasses() [styleID] ) );
+			return getOpenTag ( docStyle.getKeywordStyle ( currentSyntax->getKeywordClasses() [styleID] ) );
 		}
-		return getOpenTag ( langInfo.getKeywordClasses() [styleID] );
+		return getOpenTag ( currentSyntax->getKeywordClasses() [styleID] );
 	}
 
 	string HtmlGenerator::getKeywordCloseTag ( unsigned int styleID )
@@ -466,7 +442,7 @@ namespace highlight
 			tagStream<<" | ";
 		}
 		maskString ( tagStream, info.file ) ;
-		tagStream<<"\">";
+		tagStream << "\">";
 		return tagStream.str();
 	}
 	string  HtmlGenerator::getMetaInfoCloseTag()
