@@ -29,6 +29,7 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #include <QtGui/QMainWindow>
 #include <QtGui/QMessageBox>
 #include <QtGui/QFileDialog>
+#include <QtGui/QListWidget>
 #include <QSettings>
 #include <QDir>
 #include <QClipboard>
@@ -39,11 +40,12 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #include <QTextStream>
 #include <QScrollBar>
 #include <QDropEvent>
+#include <QDesktopServices>
 
 #include "version.h"
 #include "codegenerator.h"
 #include "htmlgenerator.h"
-#include "configurationreader.h"
+
 
 #include "enums.h"
 
@@ -62,13 +64,14 @@ public:
     MainWindow(QWidget *parent = 0);
     ~MainWindow();
 
-    void addInputFiles(const QStringList& list);
+    void addInputFiles(const QStringList& list, QListWidget* listWidget, const QString &iconName=":/file.png", bool checkable=false);
 
 private:
     Ui::MainWindowClass *ui;
     StringMap extensions,  shebangs;
     QString fileOpenFilter;
     QString savedClipboardContent;
+    bool getDataFromCP;
 
     void readSettings();
     void writeSettings();
@@ -100,7 +103,12 @@ public slots:
     void on_pbCopyFile2CP_clicked();
 
 private slots:
-
+    void on_lvPluginScripts_itemClicked(QListWidgetItem* item);
+    void on_actionVisit_website_triggered();
+    void on_pbClearAllPlugins_clicked();
+    void on_pbClearAll_clicked();
+    void on_pbClearSelPlugin_clicked();
+    void on_pbSelectPlugin_clicked();
     void on_pbCopyToCP_clicked();
     void on_pbPasteFromCB_clicked();
     void on_actionAbout_translations_triggered();
